@@ -27,7 +27,7 @@ my_download_file <- function(dl_link,
 
       # fix for issue 13: https://github.com/msperlin/GetDFPData/issues/13
       my.OS <- tolower(Sys.info()["sysname"])
-      if (my.OS == 'windows') {
+      if (my.OS %in% c('windows', 'darwin')) {
         utils::download.file(url = dl_link,
                              destfile = dest_file,
                              #method = 'wget',
